==> wflogs_0.9.7.orig.tar.gz: wflogs-0.9.7/logs/filter_y.h <==
/* A Bison parser, made from filter_y.yy, by GNU bison 1.75.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

#ifndef BISON_Y_TAB_H
# define BISON_Y_TAB_H

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     ALL = 258,
     NULLNETWORK = 259,
     NOT = 260,
     PROTO = 261,
     IPADDR = 262,
     IPNET = 263,
     MACADDR = 264,
     INTNUM = 265,
     NAME = 266,
     STRING = 267,
     IP = 268,
     UDP = 269,
     TCP = 270,
     ICMP = 271,
     ECHO_REPLY = 272,
     DESTINATION_UNREACHABLE = 273,
     NETWORK_UNREACHABLE = 274,
     HOST_UNREACHABLE = 275,
     PROTOCOL_UNREACHABLE = 276,
     PORT_UNREACHABLE = 277,
     FRAGMENTATION_NEEDED = 278,
     SOURCE_ROUTE_FAILED = 279,
     NETWORK_UNKNOWN = 280,
     HOST_UNKNOWN = 281,
     NETWORK_PROHIBITED = 282,
     HOST_PROHIBITED = 283,
     TOS_NETWORK_UNREACHABLE = 284,
     TOS_HOST_UNREACHABLE = 285,
     COMMUNICATION_PROHIBITED = 286,
     HOST_PRECEDENCE_VIOLATION = 287,
     PRECEDENCE_CUTOFF = 288,
     SOURCE_QUENCH = 289,
     REDIRECT = 290,
     NETWORK_REDIRECT = 291,
     HOST_REDIRECT = 292,
     TOS_NETWORK_REDIRECT = 293,
     TOS_HOST_REDIRECT = 294,
     ECHO_REQUEST = 295,
     ROUTER_ADVERTISEMENT = 296,
     ROUTER_SOLICITATION = 297,
     TIME_EXCEEDED = 298,
     TTL_ZERO_DURING_TRANSIT = 299,
     TTL_ZERO_DURING_REASSEMBLY = 300,
     PARAMETER_PROBLEM = 301,
     IP_HEADER_BAD = 302,
     REQUIRED_OPTION_MISSING = 303,
     TIMESTAMP_REQUEST = 304,
     TIMESTAMP_REPLY = 305,
     INFO_REQUEST = 306,
     INFO_REPLY = 307,
     ADDRESS_MASK_REQUEST = 308,
     ADDRESS_MASK_REPLY = 309,
     TCP_FLAGS = 310,
     LE_OP = 311,
     GE_OP = 312,
     EQ_OP = 313,
     NE_OP = 314,
     REG_OP = 315,
     LAND_OP = 316,
     LOR_OP = 317,
     IDENTIFIER = 318,
     STRING_LITERAL = 319,
     STRING_REGEXP = 320,
     DATE_STRING = 321
   };
#endif
#define ALL 258
#define NULLNETWORK 259
#define NOT 260
#define PROTO 261
#define IPADDR 262
#define IPNET 263
#define MACADDR 264
#define INTNUM 265
#define NAME 266
#define STRING 267
#define IP 268
#define UDP 269
#define TCP 270
#define ICMP 271
#define ECHO_REPLY 272
#define DESTINATION_UNREACHABLE 273
#define NETWORK_UNREACHABLE 274
#define HOST_UNREACHABLE 275
#define PROTOCOL_UNREACHABLE 276
#define PORT_UNREACHABLE 277
#define FRAGMENTATION_NEEDED 278
#define SOURCE_ROUTE_FAILED 279
#define NETWORK_UNKNOWN 280
#define HOST_UNKNOWN 281
#define NETWORK_PROHIBITED 282
#define HOST_PROHIBITED 283
#define TOS_NETWORK_UNREACHABLE 284
#define TOS_HOST_UNREACHABLE 285
#define COMMUNICATION_PROHIBITED 286
#define HOST_PRECEDENCE_VIOLATION 287
#define PRECEDENCE_CUTOFF 288
#define SOURCE_QUENCH 289
#define REDIRECT 290
#define NETWORK_REDIRECT 291
#define HOST_REDIRECT 292
#define TOS_NETWORK_REDIRECT 293
#define TOS_HOST_REDIRECT 294
#define ECHO_REQUEST 295
#define ROUTER_ADVERTISEMENT 296
#define ROUTER_SOLICITATION 297
#define TIME_EXCEEDED 298
#define TTL_ZERO_DURING_TRANSIT 299
#define TTL_ZERO_DURING_REASSEMBLY 300
#define PARAMETER_PROBLEM 301
#define IP_HEADER_BAD 302
#define REQUIRED_OPTION_MISSING 303
#define TIMESTAMP_REQUEST 304
#define TIMESTAMP_REPLY 305
#define INFO_REQUEST 306
#define INFO_REPLY 307
#define ADDRESS_MASK_REQUEST 308
#define ADDRESS_MASK_REPLY 309
#define TCP_FLAGS 310
#define LE_OP 311
#define GE_OP 312
#define EQ_OP 313
#define NE_OP 314
#define REG_OP 315
#define LAND_OP 316
#define LOR_OP 317
#define IDENTIFIER 318
#define STRING_LITERAL 319
#define STRING_REGEXP 320
#define DATE_STRING 321




#ifndef YYSTYPE
#line 69 "filter_y.yy"
typedef union {
  int intval;
  char* str;
  wf_ipaddr* ipaddr;
  wf_network* network;
  wf_macaddr* macaddr;
  exprnode* node;
  enum filter_op_unary unary;
} yystype;
/* Line 1281 of /usr/share/bison/yacc.c.  */
#line 182 "y.tab.h"
# define YYSTYPE yystype
#endif

extern YYSTYPE yylval;


#endif /* not BISON_Y_TAB_H */

==> wflogs_0.9.8.orig.tar.gz: wflogs-0.9.8/logs/filter_y.h <==
/* A Bison parser, made by GNU Bison 1.875a.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     ALL = 258,
     NULLNETWORK = 259,
     NOT = 260,
     PROTO = 261,
     IPADDR = 262,
     IPNET = 263,
     MACADDR = 264,
     INTNUM = 265,
     NAME = 266,
     STRING = 267,
     IP = 268,
     UDP = 269,
     TCP = 270,
     ICMP = 271,
     TCP_FLAGS = 272,
     LE_OP = 273,
     GE_OP = 274,
     EQ_OP = 275,
     NE_OP = 276,
     REG_OP = 277,
     LAND_OP = 278,
     LOR_OP = 279,
     IDENTIFIER = 280,
     STRING_LITERAL = 281,
     STRING_REGEXP = 282,
     DATE_STRING = 283
   };
#endif
#define ALL 258
#define NULLNETWORK 259
#define NOT 260
#define PROTO 261
#define IPADDR 262
#define IPNET 263
#define MACADDR 264
#define INTNUM 265
#define NAME 266
#define STRING 267
#define IP 268
#define UDP 269
#define TCP 270
#define ICMP 271
#define TCP_FLAGS 272
#define LE_OP 273
#define GE_OP 274
#define EQ_OP 275
#define NE_OP 276
#define REG_OP 277
#define LAND_OP 278
#define LOR_OP 279
#define IDENTIFIER 280
#define STRING_LITERAL 281
#define STRING_REGEXP 282
#define DATE_STRING 283




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 69 "filter_y.yy"
typedef union YYSTYPE {
  int intval;
  char* str;
  wf_ipaddr* ipaddr;
  wf_network* network;
  wf_macaddr* macaddr;
  exprnode* node;
  enum filter_op_unary unary;
} YYSTYPE;
/* Line 1240 of yacc.c.  */
#line 103 "y.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;
